@@ -1,4 +1,5 @@
 #![allow(unused_imports)]
+#![allow(clippy::all)]
 use super::*;
 use wasm_bindgen::prelude::*;
 #[wasm_bindgen]
@@ -9,6 +10,16 @@ extern "C" {
     #[doc = ""]
     #[doc = "*This API requires the following crate features to be activated: `MediaKeysPolicy`*"]
     pub type MediaKeysPolicy;
+    #[doc = "Get the `minHdcpVersion` field of this object."]
+    #[doc = ""]
+    #[doc = "*This API requires the following crate features to be activated: `MediaKeysPolicy`*"]
+    #[wasm_bindgen(method, getter = "minHdcpVersion")]
+    pub fn get_min_hdcp_version(this: &MediaKeysPolicy) -> Option<::alloc::string::String>;
+    #[doc = "Change the `minHdcpVersion` field of this object."]
+    #[doc = ""]
+    #[doc = "*This API requires the following crate features to be activated: `MediaKeysPolicy`*"]
+    #[wasm_bindgen(method, setter = "minHdcpVersion")]
+    pub fn set_min_hdcp_version(this: &MediaKeysPolicy, val: &str);
 }
 impl MediaKeysPolicy {
     #[doc = "Construct a new `MediaKeysPolicy`."]
@@ -19,21 +30,9 @@ impl MediaKeysPolicy {
         let mut ret: Self = ::wasm_bindgen::JsCast::unchecked_into(::js_sys::Object::new());
         ret
     }
-    #[doc = "Change the `minHdcpVersion` field of this object."]
-    #[doc = ""]
-    #[doc = "*This API requires the following crate features to be activated: `MediaKeysPolicy`*"]
+    #[deprecated = "Use `set_min_hdcp_version()` instead."]
     pub fn min_hdcp_version(&mut self, val: &str) -> &mut Self {
-        use wasm_bindgen::JsValue;
-        let r = ::js_sys::Reflect::set(
-            self.as_ref(),
-            &JsValue::from("minHdcpVersion"),
-            &JsValue::from(val),
-        );
-        debug_assert!(
-            r.is_ok(),
-            "setting properties should never fail on our dictionary objects"
-        );
-        let _ = r;
+        self.set_min_hdcp_version(val);
         self
     }
 }
